@@ -7,11 +7,11 @@
 ''' Base classes for Data Loader interface
 
 '''
+from yaml import dump
 
 from .cache import make_caches
-from ..utils import make_path_posix, DictSerialiseMixin
-import sys
-PY2 = sys.version_info[0] == 2
+from ..utils import make_path_posix, DictSerialiseMixin, pretty_describe
+import warnings
 
 
 class Schema(dict):
@@ -29,10 +29,14 @@ class Schema(dict):
         kwargs: typically include datashape, dtype, shape
         """
         super(Schema, self).__init__(**kwargs)
-        for field in ['datashape', 'dtype', 'extra_metadata', 'shape']:
+        for field in ['datashape', 'dtype', 'shape']:
             # maybe a default-dict
             if field not in self:
                 self[field] = None
+        if 'npartitions' not in self:
+            self['npartitions'] = 1
+        if 'extra_metadata' not in self:
+            self['extra_metadata'] = {}
 
     def __repr__(self):
         return ("<Schema instance>\n"
@@ -45,6 +49,10 @@ class Schema(dict):
         return self[item]
 
 
+class NoEntry(AttributeError):
+    pass
+
+
 class DataSource(DictSerialiseMixin):
     """An object which can produce data
 
@@ -87,6 +95,7 @@ class DataSource(DictSerialiseMixin):
         self.catalog_object = None
         self.on_server = False
         self.cat = None  # the cat from which this source was made
+        self._entry = None
 
     def _get_cache(self, urlpath):
         if len(self.cache) == 0:
@@ -125,21 +134,15 @@ class DataSource(DictSerialiseMixin):
         import inspect
         kwargs = self._captured_init_kwargs.copy()
         meta = kwargs.pop('metadata', self.metadata) or {}
-        if PY2:
-            kwargs.update(dict(zip(inspect.getargspec(self.__init__).args,
-                          self._captured_init_args)))
-        else:
-            kwargs.update(dict(zip(inspect.signature(self.__init__).parameters,
-                                   self._captured_init_args)))
-        data = {'sources': {self.name: {
+        kwargs.update(dict(zip(inspect.signature(self.__init__).parameters,
+                           self._captured_init_args)))
+        data = {'sources':
+                {self.name: {
             'driver': self.classname,
             'description': self.description or "",
             'metadata': meta,
             'args': kwargs
         }}}
-        if with_plugin:
-            data['plugins'] = {
-                'source': [{'module': self.__module__}]}
         return data
 
     def yaml(self, with_plugin=False):
@@ -155,10 +158,24 @@ class DataSource(DictSerialiseMixin):
             is created with a plugin not expected to be in the global Intake
             registry.
         """
-        from yaml import dump
         data = self._yaml(with_plugin=with_plugin)
         return dump(data, default_flow_style=False)
 
+    def _ipython_display_(self):
+        """Display the entry as a rich object in an IPython session."""
+        from IPython.display import display
+        data = self._yaml()['sources']
+        contents = dump(data, default_flow_style=False)
+        display({
+            'application/json': contents,
+            'text/plain': pretty_describe(contents)
+        }, metadata={
+            'application/json': {'root': self.name}
+        }, raw=True)
+
+    def __repr__(self):
+        return self.yaml()
+
     @property
     def plots(self):
         """List custom associated quick-plots """
@@ -215,6 +232,49 @@ class DataSource(DictSerialiseMixin):
         """
         raise NotImplementedError
 
+    @property
+    def entry(self):
+        warnings.warn("direct access to the entry is deprecated", stacklevel=2)
+        if self._entry is None:
+            raise NoEntry("Source was not made from a catalog entry")
+        return self._entry
+
+    def configure_new(self, **kwargs):
+        """Create a new instance of this source with altered arguments
+
+        Enables the picking of options and re-evaluating templates from any
+        user-parameters associated with
+        this source, or overriding any of the init arguments.
+
+        Returns a new data source instance. The instance will be recreated from
+        the original entry definition in a catalog **if** this source was originally
+        created from a catalog.
+        """
+        if self._entry is not None:
+            obj = self._entry(**kwargs)
+            obj._entry = self._entry
+            return obj
+        else:
+            kw = self._captured_init_kwargs.copy()
+            kw.update(kwargs)
+            return type(self)(*self._captured_init_args, **kw)
+
+    __call__ = get = configure_new  # compatibility aliases
+
+    def describe(self):
+        if self._entry is None:
+            raise NoEntry("Source was not made from a catalog entry")
+
+        return self._entry.describe()
+
+    @property
+    def gui(self):
+        """Source GUI, with parameter selection and plotting"""
+        if self._entry is None:
+            raise NoEntry("Source was not made from a catalog entry")
+
+        return self._entry.gui
+
     def close(self):
         """Close open resources corresponding to this data source."""
         self._close()
@@ -270,9 +330,8 @@ class DataSource(DictSerialiseMixin):
             version was written.
         kargs: passed to the _persist method on the base container.
         """
-        from ..container import container_map
         from ..container.persist import PersistStore
-        import time
+        from dask.base import tokenize
         if 'original_tok' in self.metadata:
             raise ValueError('Cannot persist a source taken from the persist '
                              'store')
@@ -286,7 +345,7 @@ class DataSource(DictSerialiseMixin):
             'cat': {} if self.cat is None else self.cat.__getstate__()
         })
         out.name = self.name
-        store.add(self._tok, out)
+        store.add(tokenize(self), out)
         return out
 
     def export(self, path, **kwargs):
@@ -304,6 +363,7 @@ class DataSource(DictSerialiseMixin):
     def _export(self, path, **kwargs):
         from ..container import container_map
         import time
+        from dask.base import tokenize
         method = container_map[self.container]._persist
         # may need to create path - access file-system method
         out = method(self, path=path, **kwargs)
@@ -312,7 +372,7 @@ class DataSource(DictSerialiseMixin):
                     'original_metadata': self.metadata,
                     'original_source': self.__getstate__(),
                     'original_name': self.name,
-                    'original_tok': self._tok,
+                    'original_tok': tokenize(self),
                     'persist_kwargs': kwargs}
         out.metadata = metadata
         out.name = self.name
@@ -320,7 +380,8 @@ class DataSource(DictSerialiseMixin):
 
     def get_persisted(self):
         from ..container.persist import store
-        return store[self._tok]()
+        from dask.base import tokenize
+        return store[tokenize(self)]()
 
     @staticmethod
     def _persist(source, path, **kwargs):
@@ -330,7 +391,8 @@ class DataSource(DictSerialiseMixin):
     @property
     def has_been_persisted(self):
         from ..container.persist import store
-        return self._tok in store
+        from dask.base import tokenize
+        return tokenize(self) in store
 
     @property
     def is_persisted(self):
